@@ -28,3 +28,11 @@ unitizer_sect("bench_mark", {
   capt_wo_time(bench_mark(Sys.sleep(.01), times=10))
   capt_wo_time(bench_mark(1 + 1, NULL, times=100))
 })
+unitizer_sect("sort pair lists", {
+  vetr:::list_as_sorted_vec(pairlist(c=1, a=list(), b=NULL))
+  # # equal names not stable, but we should never hit this with attribute lists
+  # vetr:::list_as_sorted_vec(pairlist(a=1, a=list(), a=NULL))
+  vetr:::list_as_sorted_vec(pairlist(b=1, 2, a=3))
+  vetr:::list_as_sorted_vec(pairlist())
+  vetr:::list_as_sorted_vec(pairlist(a=1))
+})
